from sqlalchemy import Column, String, Integer, DateTime
from sqlalchemy.dialects.postgresql import UUID
from sqlalchemy.sql import func
from core.database import Base
import uuid

class Fruit(Base):
    __tablename__ = "fruits"

    id = Column(UUID(as_uuid=True), primary_key=True, default=uuid.uuid4)
    name = Column(String, nullable=False, unique=True, index=True)
    description = Column(String, nullable=True)
    price = Column(Integer, nullable=False)
    created_at = Column(DateTime, default=func.now())
    updated_at = Column(DateTime, default=func.now(), onupdate=func.now())

    @classmethod
    def create_new_fruit(cls, name, description, price):
        new_fruit = cls(name=name, description=description, price=price)
        return new_fruit

    @classmethod
    def update_fruit(cls, fruit_id, name=None, description=None, price=None):
        fruit = cls.query.get(fruit_id)
        if name:
            fruit.name = name
        if description:
            fruit.description = description
        if price:
            fruit.price = price
        return fruit